.. include:: globals.rst
.. _index:

===================
django-adminactions
===================

.. image:: https://secure.travis-ci.org/saxix/django-adminactions.png?branch=master
   :target: http://travis-ci.org/saxix/django-adminactions/

.. image:: https://codecov.io/github/saxix/django-adminactions/coverage.svg?branch=master
       :target: https://codecov.io/github/saxix/django-adminactions?branch=develop


Collection of useful actions to use with django.contrib.admin.ModelAdmin and/or django.contrib.admin.AdminSite


Table Of Contents
=================

.. toctree::
    :maxdepth: 1

    install
    contributing
    actions
    signals
    exceptions
    api
    howto
    faq

Project Info
============
.. toctree::
    :maxdepth: 1

    changes
    authors


.. toctree::
    :hidden:

    globals

Links
=====

   * Project home page: https://github.com/saxix/django-adminactions
   * Issue tracker: https://github.com/saxix/django-adminactions/issues?sort
   * Download: http://pypi.python.org/pypi/django-adminactions/
   * Documentation: http://readthedocs.org/docs/django-adminactions/en/latest/

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
